package nl.nikhef.safaripark;

import java.util.HashSet;
import java.util.Set;

import javax.inject.Inject;

import nl.nikhef.safaripark.extra.Module;
import nl.nikhef.sfp.SFPDevice;
import nl.nikhef.sfp.SFPManager;
import nl.nikhef.sfp.ddmi.DDMILoader;

public class AppContext {

	public final SFPManager sfpMgr;
	public final DDMILoader ddmiLdr;
	public final OverlayManager ovlMgr;
	public final ContextCache ctxCache;
	
	private final Set<Module> _locks = new HashSet();
	
	@Inject
	public AppContext(SFPManager sfpMgr, DDMILoader ddmiLdr, OverlayManager ovlMgr) {
		this.sfpMgr = sfpMgr;
		this.ddmiLdr = ddmiLdr;
		this.ovlMgr = ovlMgr;
		this.ctxCache = new ContextCache(sfpMgr, ddmiLdr);
	}
	
	
	
	public boolean isLocked(Module m)
	{
		return _locks.contains(m);
	}
	
	public boolean lock(Module m)
	{
		if (_locks.contains(m)) return false;
		_locks.add(m);
		return true;
	}
	
	public void unlock(Module m) 
	{
		if (!_locks.contains(m)) throw new RuntimeException("Module unlocked w/o being locked");
		_locks.remove(m);
	}

}
